@@ -9,6 +9,7 @@ class KnockPY(object):
                     virustotalapi=None, 
                     discoveryapi=None, 
                     securitytrail=None,
+                    binary_edge_api=None,
                     ua=None):
                         
         self.domain = domain 
@@ -16,6 +17,7 @@ class KnockPY(object):
         self.virustotalapi = virustotalapi
         self.discoveryapi = discoveryapi
         self.securitytrail = securitytrail
+        self.binary_edge_api = binary_edge_api
         self.ua=ua
         self.timeout = 50
         
@@ -150,9 +152,39 @@ class KnockPY(object):
             print("[Knockpy securitytrails ERROR]", e, flush=True)
             return []
             
+    async def binary_edge(self):
+        """@return List"""
+        try:
+            if not self.binary_edge_api:
+                return [] 
+                
+            headers = {"X-KEY":self.binary_edge_api, "User-Agent":self.ua}
+            url = "https://api.binaryedge.io/v2/query/domains/subdomain/{domain}".format(domain=self.domain)
+            subdomains = []
+            
+            async with httpx.AsyncClient() as client:
+                resp = await client.get(url, headers=headers, timeout=self.timeout)
+                
+                if(resp.status_code == 200):
+                    data = resp.json()
+                    page = data.get("page")
+                    subdomains += data.get("events")
+                    
+                    if(page == 1):
+                        return subdomains 
+                    else:
+                        return subdomains
+                        
+        except Exception as e:
+            print("[Knockpy binary_edge ERROR]", e, flush=True)
+            return []
+            
     async def search(self, resolve=False, return_dict=True):
         subdomains = []
 
+        print("Searching binary_edge")
+        subdomains += await self.binary_edge()
+        
         print("Searching virustotal")
         subdomains += await self.virustotal()
         
